@@ -1,3 +1,5 @@
+import random
+import string
 import re
 import subprocess
 import time
@@ -73,6 +75,8 @@ class TemplateProcessor:
         self.processed_templates = get_processed_templates()
         self.kwargs = {}
         self.folder_path = False
+        charVal = (random.choice(string.ascii_letters) for x in range(5))
+        self.randomstr = ''.join(charVal)
     
     def append_exclude_directories(self, dirs):
         """
@@ -334,7 +338,7 @@ class TemplateProcessor:
             template_node['resourceTypes'] = list(set(template_node.get('resourceTypes', [])))
             count = count + 1
             node_dict = {
-                "snapshotId": '%s%s' % (master_snapshot_id, str(count)),
+                "snapshotId": '%s%s%s' % (master_snapshot_id, self.randomstr, str(count)),
                 "type": template_node.get("node_type", self.node["type"]),
                 "collection": collection,
                 "paths": template_node["paths"],
@@ -573,7 +577,7 @@ class TemplateProcessor:
                             "validate" : self.node['validate'] if 'validate' in self.node else True
                         })
             
-            nodes, count = self.create_node_record(generated_template_file_list, count)	
+            nodes, count = self.create_node_record(generated_template_file_list, count)
             if self.node['masterSnapshotId'] not in self.snapshot_data or not isinstance(self.snapshot_data[self.node['masterSnapshotId']], list):	
                 self.snapshot_data[self.node['masterSnapshotId']] = []	
             self.snapshot_data[self.node['masterSnapshotId']] = self.snapshot_data[self.node['masterSnapshotId']] + nodes	
